@@ -63,7 +63,7 @@ void SuggestionDataBase::initXapianDb() {
 
   auto xapianEntry = Entry(impl, entry_index_type(r.second));
   auto accessInfo = xapianEntry.getItem().getDirectAccessInformation();
-  if (accessInfo.second == 0) {
+  if (!accessInfo.isValid()) {
       return;
   }
 
@@ -143,7 +143,7 @@ Xapian::Query SuggestionDataBase::parseQuery(const std::string& query)
   m_queryParser.set_stemming_strategy(Xapian::QueryParser::STEM_SOME);
   xquery = m_queryParser.parse_query(query, flags);
 
-  if ( !query.empty() && xquery.get_num_subqueries() == 0 ) {
+  if ( !query.empty() && xquery.empty() ) {
     // a non-empty query string produced an empty xapian query which means
     // that the query string is made solely of punctuation.
     xquery = Xapian::Query(Xapian::Query::OP_WILDCARD, query);
@@ -210,42 +210,46 @@ SuggestionSearch::SuggestionSearch(SuggestionSearch&& s) = default;
 SuggestionSearch& SuggestionSearch::operator=(SuggestionSearch&& s) = default;
 SuggestionSearch::~SuggestionSearch() = default;
 
+#if ! defined(ENABLE_XAPIAN)
+#define TRY_UTILIZING_SUGGESTIONDB(CODE) // empty
+#else
+#define TRY_UTILIZING_SUGGESTIONDB(CODE) \
+  if (mp_internalDb->hasDatabase()) {                                   \
+    try {                                                               \
+      CODE                                                              \
+    } catch(...) {                                                      \
+      std::cerr << "There was a problem utilizing the suggestions DB, " \
+                << "switching to title listing mode."                   \
+                << std::endl;                                           \
+    }                                                                   \
+  }
+#endif
+
+
 int SuggestionSearch::getEstimatedMatches() const
 {
-#if defined(ENABLE_XAPIAN)
-  if (mp_internalDb->hasDatabase()) {
-    try {
-      auto enquire = getEnquire();
-      // Force xapian to check at least 10 documents even if we ask for an empty mset.
-      // Else, the get_matches_estimated may be wrong and return 0 even if we have results.
-      auto mset = enquire.get_mset(0, 0, 10);
-      return mset.get_matches_estimated();
-    } catch(...) {
-      std::cerr << "Query Parsing failed, Switching to search without index." << std::endl;
-    }
-  }
-#endif  // ENABLE_XAPIAN
+  TRY_UTILIZING_SUGGESTIONDB(
+    auto enquire = getEnquire();
+    // Force xapian to check at least 10 documents even if we ask for an
+    // empty mset. Else, the get_matches_estimated() may be wrong and return 0
+    // even if we have results.
+    auto mset = enquire.get_mset(0, 0, 10);
+    return mset.get_matches_estimated();
+  );
 
   return mp_internalDb->m_archive.findByTitle(m_query).size();
 }
 
 const SuggestionResultSet SuggestionSearch::getResults(int start, int maxResults) const {
-#if defined(ENABLE_XAPIAN)
-    if (mp_internalDb->hasDatabase())
-    {
-      try {
-        auto enquire = getEnquire();
-        auto mset = enquire.get_mset(start, maxResults);
-        return SuggestionResultSet(mp_internalDb, std::move(mset));
-      } catch(...) {
-        std::cerr << "Query Parsing failed, Switching to search without index." << std::endl;
-      }
-    }
-#endif  // ENABLE_XAPIAN
+  TRY_UTILIZING_SUGGESTIONDB(
+    auto enquire = getEnquire();
+    auto mset = enquire.get_mset(start, maxResults);
+    return SuggestionResultSet(mp_internalDb, std::move(mset));
+  );
 
-    auto entryRange = mp_internalDb->m_archive.findByTitle(m_query);
-    entryRange.offset(start, maxResults);
-    return SuggestionResultSet(entryRange);
+  auto entryRange = mp_internalDb->m_archive.findByTitle(m_query);
+  entryRange = entryRange.offset(start, maxResults);
+  return SuggestionResultSet(entryRange);
 }
 
 const void SuggestionSearch::forceRangeSuggestion() {
@@ -293,7 +297,7 @@ Xapian::Enquire& SuggestionSearch::getEnquire() const
     return *mp_enquire;
 }
 
-SuggestionResultSet::SuggestionResultSet(std::shared_ptr<SuggestionDataBase> p_internalDb, Xapian::MSet&& mset) :
+SuggestionResultSet::SuggestionResultSet(SuggestionDBPtr p_internalDb, Xapian::MSet&& mset) :
   mp_internalDb(p_internalDb),
   mp_entryRange(nullptr),
   mp_mset(std::make_shared<Xapian::MSet>(mset))
@@ -319,26 +323,4 @@ int SuggestionResultSet::size() const
   return mp_entryRange->size();
 }
 
-SuggestionResultSet::iterator SuggestionResultSet::begin() const
-{
-#if defined(ENABLE_XAPIAN)
-    if ( ! mp_entryRange ) {
-        return new iterator::SuggestionInternalData(mp_internalDb, mp_mset, mp_mset->begin());
-    }
-#endif  // ENABLE_XAPIAN
-
-    return iterator(mp_entryRange->begin());
-}
-
-SuggestionResultSet::iterator SuggestionResultSet::end() const
-{
-#if defined(ENABLE_XAPIAN)
-    if ( ! mp_entryRange ) {
-        return new iterator::SuggestionInternalData(mp_internalDb, mp_mset, mp_mset->end());
-    }
-#endif  // ENABLE_XAPIAN
-
-    return iterator(mp_entryRange->end());
-}
-
 } // namespace zim
